@@ -55,3 +55,18 @@ def monkeypatch_class(name, bases, namespace):
         if name != "__metaclass__":
             setattr(base, name, value)
     return base
+
+
+def get_model_name(opts):
+    try:
+        return opts.model_name
+    except AttributeError:
+        return opts.module_name
+
+
+def get_permission_codename(action, opts):
+    """
+    Backport of django.contrib.auth.get_permission_codename for older versions
+    of Django.
+    """
+    return '%s_%s' % (action, get_model_name(opts))
