@@ -40,13 +40,16 @@ def format_exception(e):
 
 # ------------------------------------------------------------------------
 @register.assignment_tag(takes_context=True)
-def feincms_nav(context, feincms_page, level=1, depth=1):
+def feincms_nav(context, feincms_page, level=1, depth=1, group=None):
     """
     Saves a list of pages into the given context variable.
     """
 
     page_class = _get_page_model()
 
+    if feincms_page is None:
+        return []
+
     if isinstance(feincms_page, HttpRequest):
         try:
             feincms_page = page_class.objects.for_request(
@@ -149,6 +152,15 @@ def feincms_nav(context, feincms_page, level=1, depth=1):
 
         queryset = _navext_filter(queryset)
 
+    if group is not None:
+        # navigationgroups extension support
+        def _navigationgroup_filter(iterable):
+            for elem in iterable:
+                if getattr(elem, 'navigation_group', None) == group:
+                    yield elem
+
+        queryset = _navigationgroup_filter(queryset)
+
     # Return a list, not a generator so that it can be consumed
     # several times in a template.
     return list(queryset)
