@@ -1,14 +1,3 @@
-if(!Array.indexOf) {
-    Array.prototype.indexOf = function(obj) {
-        for(var i=0; i<this.length; i++) {
-            if(this[i]==obj) {
-                return i;
-            }
-        }
-        return -1;
-    };
-}
-
 (function($){
     // Patch up urlify maps to generate nicer slugs in german
     if(typeof(Downcoder) != "undefined"){
@@ -206,6 +195,8 @@ if(!Array.indexOf) {
             var old_region_id = REGION_MAP.indexOf(item.find("."+field).val());
             item.find("."+field).val(REGION_MAP[value]);
 
+            // show/hide the empty machine message in the source and
+            // target region.
             old_region_item = $("#"+REGION_MAP[old_region_id]+"_body");
             if (old_region_item.children("div.order-machine").children().length == 0)
                 old_region_item.children("div.empty-machine-msg").show();
@@ -337,26 +328,78 @@ if(!Array.indexOf) {
         });
     }
 
+    function create_tabbed(_tab_selector, _main_selector, _switch_cb) {
+        var tab_selector = _tab_selector,
+            main_selector = _main_selector,
+            switch_cb = _switch_cb;
+
+        $(tab_selector).addClass('clearfix');
+
+        $(tab_selector + " > .navi_tab").on('click', function() {
+            var elem = $(this),
+                tab_str = elem.attr("id").substr(0, elem.attr("id").length-4);
+
+            if (elem.hasClass('tab_active') && tab_str.indexOf('extension_option') != -1) {
+                elem.removeClass('tab_active');
+                $('#' + tab_str + '_body').hide();
+            } else {
+
+                $(tab_selector + " > .navi_tab").removeClass("tab_active");
+                elem.addClass("tab_active");
+                $(main_selector + " > div:visible, " + main_selector + " > fieldset:visible").hide();
+
+                $('#'+tab_str+'_body').show();
+
+                if(switch_cb) {
+                    switch_cb(tab_str);
+                }
+            }
+        });
+    }
+
     // global variable holding the current template key
     var current_template;
 
     $(document).ready(function($){
         hide_form_rows_with_hidden_widgets();
 
-        $("#main_wrapper > .navi_tab").click(function(){
-            var elem = $(this);
-            $("#main_wrapper > .navi_tab").removeClass("tab_active");
-            elem.addClass("tab_active");
-            $("#main > div:visible, #main > fieldset:visible").hide();
-
-            var tab_str = elem.attr("id").substr(0, elem.attr("id").length-4);
-            $('#'+tab_str+'_body').show();
+        create_tabbed('#main_wrapper', '#main', function(tab_str){
             ACTIVE_REGION = REGION_MAP.indexOf(tab_str);
-
             // make it possible to open current tab on page reload
             window.location.replace('#tab_'+tab_str);
         });
 
+        /* Rearrange the options fieldsets so we can wrap them into a tab bar */
+        var options_fieldsets = $('fieldset.collapse');
+        options_fieldsets.wrapAll('<div id="extension_options_wrapper" />');
+        var option_wrapper = $('#extension_options_wrapper');
+        var panels = [];
+
+        options_fieldsets.each(function(idx, elem) {
+            var option_title = $('h2', $(elem)).text();
+            var c = $(elem).children('div');
+            var id_base = 'extension_option_'+ idx;
+
+            $(elem).remove();
+
+            var paren = option_title.indexOf(' (');
+            if(paren > 0)
+                option_title = option_title.substr(0, paren);
+
+            option_wrapper.append('<div class="navi_tab" id="'+ id_base +'_tab">' +
+                                   option_title +
+                                   '</div>');
+            var panel = $('<fieldset class="module aligned" style="clear: both; display: none" id="' + id_base + '_body"></fieldset>');
+            panel.html(c);
+            panels.push(panel);
+        });
+
+        option_wrapper.append('<div id="extension_options" />');
+        $('#extension_options').html(panels);
+
+        create_tabbed('#extension_options_wrapper', '#extension_options');
+        /* Done morphing extension options into tabs */
+
         // save content type selects for later use
         save_content_type_selects();
 
@@ -374,46 +417,41 @@ if(!Array.indexOf) {
             update_item_controls(new_fieldset, ACTIVE_REGION);
         });
 
-        $("h2 img.item-delete").live('click', function(){
-            var popup_bg = '<div class="popup_bg"></div>';
-            $("body").append(popup_bg);
+        $(document.body).on('click', 'h2 img.item-delete', function() {
             var item = $(this).parents(".order-item");
-            jConfirm(DELETE_MESSAGES[0], DELETE_MESSAGES[1], function(r) {
-                if (r==true) {
-                    var in_database = item.find(".delete-field").length;
-                    if(in_database==0){ // remove on client-side only
-                        var id = item.find(".item-content > div").attr('id');
+            if (confirm(DELETE_MESSAGES[0])) {
+                var in_database = item.find(".delete-field").length;
+                if(in_database==0){ // remove on client-side only
+                    var id = item.find(".item-content > div").attr('id');
 
-                        // poorify all contents
-                        items = item.parents('.order-machine').find('.order-item');
-                        items.each(function() {
-                          poorify_rich($(this));
-                        })
+                    // poorify all contents
+                    items = item.parents('.order-machine').find('.order-item');
+                    items.each(function() {
+                      poorify_rich($(this));
+                    })
 
-                        // remove content
-                        django.jQuery('#'+id).find('a.inline-deletelink')
-                          .triggerHandler('click');
+                    // remove content
+                    django.jQuery('#'+id).find('a.inline-deletelink')
+                      .triggerHandler('click');
 
-                        // richify all contents again
-                        items.each(function() {
-                          richify_poor($(this));
-                        })
-                    }
-                    else{ // saved on server, don't remove form
-                        set_item_field_value(item,"delete-field","checked");
-                    }
-                    item.fadeOut(200, function() {
-                      var region_item = $("#"+REGION_MAP[ACTIVE_REGION]+"_body");
-                      if (region_item.children("div.order-machine").children(":visible").length == 0) {
-                          region_item.children("div.empty-machine-msg").show();
-                      }
-                    });
+                    // richify all contents again
+                    items.each(function() {
+                      richify_poor($(this));
+                    })
                 }
-                $(".popup_bg").remove();
-            });
+                else{ // saved on server, don't remove form
+                    set_item_field_value(item,"delete-field","checked");
+                }
+                item.fadeOut(200, function() {
+                  var region_item = $("#"+REGION_MAP[ACTIVE_REGION]+"_body");
+                  if (region_item.children("div.order-machine").children(":visible").length == 0) {
+                      region_item.children("div.empty-machine-msg").show();
+                  }
+                });
+            }
         });
 
-        $('h2 span.collapse').live('click', function(){
+        $(document.body).on('click', 'h2 span.collapse', function() {
             var node = this;
             $(this.parentNode.parentNode).children('.item-content').slideToggle(function(){
                 $(node).text(feincms_gettext($(this).is(':visible') ? 'Hide' : 'Show'));
@@ -440,9 +478,6 @@ if(!Array.indexOf) {
                 if(new_regions.indexOf(current_regions[i])==-1)
                     not_in_new.push(current_regions[i]);
 
-            var popup_bg = '<div id="popup_bg"></div>';
-            $("body").append(popup_bg);
-
             var msg = CHANGE_TEMPLATE_MESSAGES[1];
 
             if(not_in_new.length) {
@@ -452,29 +487,26 @@ if(!Array.indexOf) {
                 }, true);
             }
 
-            jConfirm(msg, CHANGE_TEMPLATE_MESSAGES[0], function(ret) {
-                if(ret) {
-                    for(var i=0; i<not_in_new.length; i++) {
-                        var body = $('#' + not_in_new[i] + '_body'),
-                            machine = body.find('.order-machine'),
-                            inputs = machine.find('input[name$=region]');
+            if (confirm(msg)) {
+                for(var i=0; i<not_in_new.length; i++) {
+                    var body = $('#' + not_in_new[i] + '_body'),
+                        machine = body.find('.order-machine'),
+                        inputs = machine.find('input[name$=region]');
 
-                        inputs.val(new_regions[0]);
-                    }
-
-                    input_element.checked = true;
-
-                    form_element.append('<input type="hidden" name="_continue" value="1" />');
-                    /* Simulate a click on the save button instead of form.submit(), so
-                       that the submit handlers from FilteredSelectMultiple get
-                       invoked. See Issue #372 */
-                    form_element.find('input[type=submit][name=_save]').click();
-
-                } else {
-                    $("div#popup_bg").remove();
-                    form_element.val($(input_element).data('original_value')); // Restore original value
+                    inputs.val(new_regions[0]);
                 }
-            });
+
+                input_element.checked = true;
+
+                form_element.append('<input type="hidden" name="_continue" value="1" />');
+                /* Simulate a click on the save button instead of form.submit(), so
+                   that the submit handlers from FilteredSelectMultiple get
+                   invoked. See Issue #372 */
+                form_element.find('input[type=submit][name=_save]').click();
+            } else {
+                // Restore original value
+                form_element.val($(input_element).data('original_value'));
+            }
 
             return false;
         }
@@ -579,7 +611,7 @@ if(!Array.indexOf) {
         }
     });
 
-    $(window).load(function(){init_contentblocks();});
+    $(window).load(init_contentblocks);
 
     // externally accessible helpers
     window.ItemEditor = {
